========
horos_io
========


.. image:: https://img.shields.io/pypi/v/horos_io.svg
        :target: https://pypi.python.org/pypi/horos_io

.. image:: https://img.shields.io/travis/santomon/horos_io.svg
        :target: https://travis-ci.com/santomon/horos_io

.. image:: https://readthedocs.org/projects/horos-io/badge/?version=latest
        :target: https://horos-io.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




handling .xml files when exported from horos; some dataset functionality


* Free software: MIT
* Documentation: https://horos-io.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `briggySmalls/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`briggySmalls/cookiecutter-pypackage`: https://github.com/briggySmalls/cookiecutter-pypackage
